#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FFS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FFS_HPP_INCLUDED

#include <nt2/bitwise/include/functions/scalar/ffs.hpp>

#endif
